@@ -438,7 +438,7 @@ class AutoCrosswalk(object):
                            df_from,
                            df_to,
                            numeric_key=None,
-                           numeric_type=None,
+                           numeric_type="categorical",
                            text_key=None):
         """
         Prepare proper crosswalk file
